export interface Mapper {
    _id?: string | null;
    /** The FQDN of the entity the mapper refer to of exist */
    entityFqdn?: string;
    /** The entity fqn - this is unique across wix */
    entityFqn?: string;
    /** The appDefId that the entity belongs to */
    appId?: string;
    /** A list of fields to translate from the entity */
    fields?: MapperField[];
    /** The name of field that hold the parent name (if exist) */
    groupByNameFieldId?: string | null;
    /** Flag to turn off sync data to localization upon domain events */
    ignoreDomainEvents?: boolean | null;
    /** The segment of the entity */
    segment?: string | null;
    /** flag that indicate the removing a repeated field in main language should remove it in all languages */
    deleteRepeatedFields?: boolean | null;
    /** Whether the entity can bt extended by Data Extensions */
    extensible?: boolean | null;
    /** The schema id that the mapper points to */
    schemaId?: string | null;
}
export interface MapperField {
    /** The field FQN */
    _id?: string;
    /** The field Type as it's shown in localization schema */
    type?: FieldType;
    /** If the field is part of a repeated fields */
    sequencePath?: SequencePath[];
    /** Option to override the field mask (the default is the id) */
    overrideMask?: string | null;
}
export declare enum FieldType {
    /** Undefined field type */
    UNDEFINED_TYPE = "UNDEFINED_TYPE",
    /** Short text TEXT */
    SHORT_TEXT = "SHORT_TEXT",
    /** Long Plain Text TEXT */
    LONG_TEXT = "LONG_TEXT",
    /** Long text including styles, images, links and more... HTML */
    RICH_TEXT = "RICH_TEXT",
    /** Wix Rich-Content-Editor format RICO */
    RICH_CONTENT_EDITOR = "RICH_CONTENT_EDITOR",
    /** Choose one from many options CSV TEXT */
    SELECTION = "SELECTION",
    /** Choose multi items from many options */
    MULTI_SELECTION = "MULTI_SELECTION",
    /** Wix document media item */
    DOCUMENT = "DOCUMENT",
    /** Wix Image media item */
    IMAGE = "IMAGE",
    /** Wix Video media item */
    VIDEO = "VIDEO",
    /** Image URL without metadata */
    IMAGE_LINK = "IMAGE_LINK"
}
export interface SequencePath {
    /** The name of the sequence the field is a part of */
    name?: string;
    /** The name of the field hold the id in the entity */
    fieldId?: string;
}
export interface Empty {
}
export interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /**
     * Unique event ID.
     * Allows clients to ignore duplicate webhooks.
     */
    _id?: string;
    /**
     * Assumes actions are also always typed to an entity_type
     * Example: wix.stores.catalog.product, wix.bookings.session, wix.payments.transaction
     */
    entityFqdn?: string;
    /**
     * This is top level to ease client code dispatching of messages (switch on entity_fqdn+slug)
     * This is although the created/updated/deleted notion is duplication of the oneof types
     * Example: created/updated/deleted/started/completed/email_opened
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example: 2020-04-26T13:57:50.699Z */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number defining the order of updates to the underlying entity.
     * For example, given that some entity was updated at 16:00 and than again at 16:01,
     * it is guaranteed that the sequence number of the second update is strictly higher than the first.
     * As the consumer, you can use this value to ensure that you handle messages in the correct order.
     * To do so, you will need to persist this number on your end, and compare the sequence number from the
     * message against the one you have stored. Given that the stored number is higher, you should ignore the message.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
export interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
export interface EntityCreatedEvent {
    entity?: string;
}
export interface RestoreInfo {
    deletedDate?: Date | null;
}
export interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
export interface EntityDeletedEvent {
    /** Entity that was deleted */
    deletedEntity?: string | null;
}
export interface ActionEvent {
    body?: string;
}
export interface LocalizedPublishedLanguageContentChanged {
    /** The action that changed the content */
    action?: LocalizationPublicAction;
    /** token to identify the flow this event is part of and the total number of event in this flow. */
    flowToken?: string | null;
}
export interface LocalizedPublishedContent {
    /** UUID identifier for content. */
    contentId?: string;
    /** compound key identifier for content. */
    contentKey?: LocalizedContentKey;
    /** content IETF BCP 47 language tag */
    languageTag?: string;
    /** localized content list of published fields. */
    languagePublishedFields?: LocalizedPublishedContentField[];
    /** Optional field that will group in the UI contents with the same group name */
    groupByName?: string | null;
}
export interface LocalizedContentKey {
    /** Schema unique key identifier */
    schemaKey?: SchemaKey;
    /** Unique identifier that represents a specific entity in the app */
    entityId?: string;
}
export interface SchemaKey {
    /** ID of app that created the schema. */
    appId?: string;
    /** Unique name defined by the creator app, used to distinguish between different entities in the the app domain. */
    entityType?: string;
    /** Scope schema is defined in (Global/Site) */
    scope?: SchemaScope;
}
export declare enum SchemaScope {
    /** Global schema, relevant to all sites */
    GLOBAL = "GLOBAL",
    /** Site schema, relevant to specific site only */
    SITE = "SITE"
}
/** contains only information relevant to UoU */
export interface LocalizedPublishedContentField extends LocalizedPublishedContentFieldValueOneOf {
    /** Field actual localized content as simple text type */
    textValue?: string;
    /** Field actual localized content as rich content editor type */
    wixRichContentEditorValue?: string;
    /** Field actual localized content as media type (image, video or document) */
    mediaValue?: MediaItem;
    /** Field unique identifier. This id has to fit to a schema field id. */
    _id?: string;
    /** In case field is reachable via sequence/s, this array represents all the sequences names in the path, and their corresponding item id. */
    sequencePath?: FieldSequence[];
}
/** @oneof */
export interface LocalizedPublishedContentFieldValueOneOf {
    /** Field actual localized content as simple text type */
    textValue?: string;
    /** Field actual localized content as rich content editor type */
    wixRichContentEditorValue?: string;
    /** Field actual localized content as media type (image, video or document) */
    mediaValue?: MediaItem;
}
export interface MediaItem extends MediaItemMediaOneOf {
    /** Image media item */
    image?: string;
    /** Video media item */
    video?: string;
    /** Document media item */
    document?: string;
}
/** @oneof */
export interface MediaItemMediaOneOf {
    /** Image media item */
    image?: string;
    /** Video media item */
    video?: string;
    /** Document media item */
    document?: string;
}
export interface FocalPoint {
    /** X-coordinate of the focal point. */
    x?: number;
    /** Y-coordinate of the focal point. */
    y?: number;
    /** crop by height */
    height?: number | null;
    /** crop by width */
    width?: number | null;
}
export interface VideoResolution {
    /** Video URL. */
    url?: string;
    /** Video height. */
    height?: number;
    /** Video width. */
    width?: number;
    /** Video format for example, mp4, hls. */
    format?: string;
}
export interface FieldSequence {
    /** Name of sequence */
    seqName?: string;
    /** Id of relevant item in the sequence */
    itemId?: string;
    /** Optional field - in case set sequences will be ordered by priority index (best effort) */
    priorityIndex?: number | null;
}
export interface CreateOrUpdateAction {
    /** The new Localized published state */
    localizedPublishedContent?: LocalizedPublishedContent;
}
export interface DeleteAction {
    /** compound key identifier for removed content. */
    contentKey?: LocalizedContentKey;
    /** content IETF BCP 47 language tag */
    languageTag?: string;
}
export interface LocalizationPublicAction extends LocalizationPublicActionActionOneOf {
    /** Content has changes in its fields */
    createOrUpdateAction?: CreateOrUpdateAction;
    /** Content deleted */
    deleteAction?: DeleteAction;
}
/** @oneof */
export interface LocalizationPublicActionActionOneOf {
    /** Content has changes in its fields */
    createOrUpdateAction?: CreateOrUpdateAction;
    /** Content deleted */
    deleteAction?: DeleteAction;
}
export interface CreateOrUpdateNileMapperRequest {
    /** A mapper to create or update if already exist */
    mapper?: Mapper;
    /** if true don't send pods notify kafka event */
    skipPodsNotify?: boolean | null;
}
export interface CreateOrUpdateNileMapperResponse {
}
export interface GetEntityMapperRequest {
    /** App id of the mapper requested */
    appId?: string;
    /** Entity fqn of the mapper requested */
    entityFqn?: string;
}
export interface GetEntityMapperResponse {
    /** Mapper requested */
    entityMapper?: Mapper;
}
export interface ListEntityMapperRequest {
    /** App id of the mapper requested */
    appId?: string | null;
    /** Entity fqn of the mapper requested */
    entityFqn?: string | null;
}
export interface ListEntityMapperResponse {
    /** Mapper requested */
    mappers?: Mapper[];
}
export interface DeleteEntityMapperRequest {
    /** App id of the mapper to delete */
    appId?: string;
    /** Entity fqn of the mapper to delete */
    entityFqn?: string;
}
export interface DeleteEntityMapperResponse {
}
export interface GetSubscribedTopicsRequest {
}
export interface GetSubscribedTopicsResponse {
    /** List of subscribed topics */
    topics?: string[];
}
export interface MessageEnvelope {
    /** App instance ID. */
    instanceId?: string | null;
    /** Event type. */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
export interface IdentificationData extends IdentificationDataIdOneOf {
    /** ID of a site visitor that has not logged in to the site. */
    anonymousVisitorId?: string;
    /** ID of a site visitor that has logged in to the site. */
    memberId?: string;
    /** ID of a Wix user (site owner, contributor, etc.). */
    wixUserId?: string;
    /** ID of an app. */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityType;
}
/** @oneof */
export interface IdentificationDataIdOneOf {
    /** ID of a site visitor that has not logged in to the site. */
    anonymousVisitorId?: string;
    /** ID of a site visitor that has logged in to the site. */
    memberId?: string;
    /** ID of a Wix user (site owner, contributor, etc.). */
    wixUserId?: string;
    /** ID of an app. */
    appId?: string;
}
export declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
export interface HtmlNewRevisionSavedMessage {
    /** HTML Site ID */
    siteId?: string;
    /** Newly saved revision */
    revision?: string;
    /** Restored from revision */
    restoredFrom?: string | null;
    /** Optional meta site id */
    metaSiteId?: string | null;
    /** Date that this version was updated (same as created) */
    updateDate?: string;
    /** determine whether this site uses responsive editor */
    isResponsive?: boolean;
    /** optional branch id if revision saved on branch */
    branchId?: string | null;
    /** determine if the new revision is a result of override save */
    overrideSave?: boolean;
    /** Optional last transaction id */
    lastTransactionId?: string | null;
    /** optional branch id if revision restored from branch */
    restoredFromBranchId?: string | null;
    /** information of revision prior to save revision operation */
    lastRevisionInfo?: RevisionInfo;
    /** new revision pages */
    pages?: Page[];
    /** the pages that were changed from the last save. Operations such as clone and restore will return an empty response at the moment. */
    changedPages?: ChangedPages;
    /** id of the main page of the site */
    mainPageId?: string;
    /** correlation id of original process (allows callers of createRevision to identify their revisions) */
    originCorrelationId?: string | null;
}
export interface RevisionInfo {
    /** revision number */
    revision?: string;
    /** last_transaction_id of revision */
    lastTransactionId?: string | null;
}
export interface Page {
    /** Page's Id */
    _id?: string;
}
export interface ChangedPages {
    /** list of updated_pages */
    updatedPages?: Page[];
    /** list of deleted_pages */
    deletedPages?: Page[];
}
export interface SyncEditorDataRequest {
    /** an optional filter for syncing the content */
    syncFilter?: SyncFilter;
}
export interface SyncFilter {
    /** content IETF BCP 47 language tag */
    languageTag?: string;
}
export interface SyncEditorDataResponse {
}
export interface PublishSiteTranslationsRequest {
    /** A language to publish it's language */
    language?: string;
}
export interface PublishSiteTranslationsResponse {
}
export interface CreateOrUpdateEditorMapperRequest {
    /** A mapper to create or update if already exist */
    mapper?: Mapper;
}
export interface CreateOrUpdateEditorMapperResponse {
}
export interface GetMapperRequest {
    /** The mapper type requested */
    entityType?: string;
}
export interface GetMapperResponse {
    /** The mapper with the entity type requested */
    mapper?: Mapper;
}
export interface DeleteMapperRequest {
    /** The entity type to delete from the service */
    entityType?: string;
}
export interface DeleteMapperResponse {
}
export interface ListMappersRequest {
}
export interface ListMappersResponse {
    /** all mappers known to editor adapter */
    mappers?: Mapper[];
}
/**
 * Update localization content with editor data
 * @public
 * @documentationMaturity preview
 * @permissionId WIX_MULTILINGUAL.TRANSLATE_APPS
 * @fqn wix.multilingual.editoradapter.v1.EditorAdapter.SyncEditorData
 */
export declare function syncEditorData(options?: SyncEditorDataOptions): Promise<void>;
export interface SyncEditorDataOptions {
    /** an optional filter for syncing the content */
    syncFilter?: SyncFilter;
}
